The PREDICTS database contains site-level summaries of the data collected
as part of the PREDICTS project - Projecting Responses of Ecological
Diversity In Changing Terrestrial Systems.
The site-level summaries are provided as a dataframe, with each row
corresponding to a site-level observation, and each column corresponding to
a variable describing the site or the observation. The data are provided in
a standardised format, with column names that are consistent across the
database.
There are two releases of the PREDICTS database, an initial release in 2016,
and an additional release in 2022. The user chooses whether to pull summary
data for the 2016 and/or 2022 release.
The data are provided under a CC NC (non-commercial) license, which means
that they cannot be used for commercial purposes. The 2016 release is
available under a CC BY-NC-SA 4.0 license, and the 2022 release is
available under a CC NC (any) license.