Learn R Programming

predictsr (version 0.2.0)

predictsr-package: predictsr: Access the 'PREDICTS' Biodiversity Database

Description

Fetches the 'PREDICTS' database and relevant metadata from the Data Portal at the Natural History Museum, London https://data.nhm.ac.uk. Data were collated from over 400 existing spatial comparisons of local-scale biodiversity exposed to different intensities and types of anthropogenic pressures, from sites around the world. These data are described in Hudson et al. (2013) tools:::Rd_expr_doi("10.1002/ece3.2579").

Arguments

Author

Maintainer: Connor Duffin connor.p.duffin@gmail.com

Other contributors:

  • The Trustees of The Natural History Museum, London [copyright holder]

See Also